@@ -9,6 +9,7 @@
 #
 # @options['search-bing.appid'] : Your Bing AppId
 # @options['search.result_filter'] : your dialy's URL format of DAY mode into Regexp.
+# @options['search-bing.base'] : Base URI of your diary (for debugging)
 #
 
 require 'timeout'
@@ -32,11 +33,16 @@ end
 def search_bing_api( q, start = 0 )
 	appid = @conf['search-bing.appid']
 
-	u = 'https://api.datamarket.azure.com/Data.ashx/Bing/SearchWeb/v1/Web'
+	u = 'https://api.datamarket.azure.com/Bing/SearchWeb/v1/Web'
 	u << "?Query=%27#{q}%27&Options=%27EnableHighlighting%27&$top=50&$skip=#{start}&$format=Json"
 	uri = URI( u )
 
-	open( uri, {:http_basic_authentication => [appid, appid]} ).read
+	begin
+		open( uri, {:http_basic_authentication => [appid, appid]} ).read
+	rescue SecurityError
+		### FIX ME: mysterious error at 1st access to the API
+		open( uri, {:http_basic_authentication => [appid, appid]} ).read
+	end
 
 ### FIX ME: this code failed on Timeout error, temporary using open-uri above.
 #	px_host, px_port = (@conf['proxy'] || '').split( /:/ )
@@ -58,12 +64,10 @@ def search_result
 	start = CGI::unescape( @cgi.params['start'][0] || '0' ).to_i
 
 	begin
-		uri = URI::parse( @conf.base_url )
-		#uri = URI::parse( 'http://sho.tdiary.net/' ) ### FOR DEBUGGING ###
+		uri = URI::parse( @conf['search-bing.base'] || @conf.base_url )
 		q = "#{query} site:#{uri.host}"
 		q << %Q| inurl:"#{uri.path}"| unless uri.path == '/'
-		xml = search_bing_api( u( q.untaint ), start )
-		json = JSON::parse( xml )
+		json = JSON::parse(search_bing_api(u(q.untaint), start))
 	rescue Net::HTTPError
 		return %Q|<p class="message">#$!</p>|
 	end
@@ -78,7 +82,7 @@ def search_result
 		r << %Q|<dd>#{search_to_html desc}</dd>|
 	end
 	r << '</dl>'
-	
+
 	r << '<div class="search-navi">'
 		# no search navi on Bing search because no total result not supported
 	r << '</div>'
